<?php
namespace FM\Service;

use FM\Factory\DashboardFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Zeedhi\Framework\DataSource\DataSet;
use Doctrine\ORM\EntityManager;
use FM\Service\FuncionariosHierarqService;

class DashboardService {

    protected $connection;
    protected $DashboardFactory;
    protected $FuncionariosHierarqService;
    protected $Environment;
    protected $newCode;

    public function __construct (EntityManager $entityManager, DashboardFactory $DashboardFactory, FuncionariosHierarqService $FuncionariosHierarqService, Environment $Environment, NewCode $newCode) {
        $this->connection                   = $entityManager->getConnection();
        $this->DashboardFactory             = $DashboardFactory;
        $this->FuncionariosHierarqService   = $FuncionariosHierarqService;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
    }

    public function getDadosLimpezaFinalizada() {

        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        return $this->DashboardFactory->getDadosLimpezaFinalizada($listaOperadores);
    }

    public function getDadosTarefaAtrasada() {

        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        return $this->DashboardFactory->getDadosTarefaAtrasada($listaOperadores);
    }

    public function getDadosTarefaConcluida() {

        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        return $this->DashboardFactory->getDadosTarefaConcluida($listaOperadores);
    }

    public function getDadosProgress(){
        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        $countTarefasConcluidas = $this->DashboardFactory->countTarefasConcluidas($listaOperadores);
        $countTarefas  = $this->DashboardFactory->countTarefas($listaOperadores);

        return[$countTarefasConcluidas,$countTarefas];
    }

    public function getDadosUltimasTarefas() {
        
        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        return $this->DashboardFactory->getDadosUltimasTarefas($listaOperadores);
    }
    
    public function getDadosResumoTarefas() {

        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        return $this->DashboardFactory->getDadosResumoTarefas($listaOperadores);
    }

    public function findLocal() {
        return $this->DashboardFactory->findLocal();
    }
    
    public function getDadosChartTarefas() {
        
        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);
       // debugApi([$listaOperadores]);

        return $this->DashboardFactory->getDadosChartTarefas($listaOperadores);
    }

    public function getDadosChartNaoConformidades() {
        
        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        return $this->DashboardFactory->getDadosChartNaoConformidades($listaOperadores);
    }

    public function getDadosChartProgressoMensal() {

        $cdoperador = $this->Environment->getCdOperador();
        $listaOperadores = $this->FuncionariosHierarqService->montarHierarquiaOperadores($cdoperador);

        return $this->DashboardFactory->countTarefasConcluidasMensal($listaOperadores);
    }

    // ------ REQUISIÇÕES DA TELA DE DASHBOARD (GERENCIAL) ----------

    public function setActivities() {

        $activities = $this->DashboardFactory->setActivities();
        return $activities;
    }

    public function getLocals($id) {

        $locals = $this->DashboardFactory->getLocals($id);
        return $locals;
    }

    public function dataBaseChartBarUnconformities($parametro) {

        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }


        $dbcb = $this->DashboardFactory->dataBaseChartBarUnconformities($param, $paramAct);
        return $dbcb;
    }

    public function dataBaseChartPieClean($parametro) {
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartPieClean($param, $paramAct);
        return $dbcp;
    }

    public function dataBaseChartBarAvgTime($parametro) {
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = "  AND LCPAI.NRLOCALCLIENTEPAI = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND LC.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartBarAvgTime($param, $paramAct);
        return $dbcp;
    }

    public function dataBaseChartPieUnit($parametro) {
        // debugApi([$parametro]);
        $param = '';
        $paramAct = '';

        if ($parametro['selectUnit'] != '' && $parametro['selectUnit'] != null) {
            $param = " AND NMPAI.NRLOCALCLIENTE = ".$parametro['selectUnit'];
        }

        if ($parametro['selectService'] != '' && $parametro['selectService'] != null) {
             $paramAct = " WHERE AC.NRATIVIDADE = ".$parametro['selectService'];
        }

        if ($parametro['selectLocal'] != '' && $parametro['selectLocal'] != null) {
             $param = " AND FCM_LOCALCLI.NRLOCALCLIENTE = ".$parametro['selectLocal'];
        }

        $dbcp = $this->DashboardFactory->dataBaseChartPieUnit($param, $paramAct);
        return $dbcp;
    }

    public function latestReports() {

        $reports = $this->DashboardFactory->latestReports();
        return $reports;
    }
    
    public function percentageTasks($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids
      $values = array (
          $this->DashboardFactory->percentageAllTasks($usersIds),
          $this->DashboardFactory->percentageTasksCompleted($usersIds)
        );
        return $values;
    }
    
    public function tasksCompleted($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids

      $tasks = $this->DashboardFactory->tasksCompleted($usersIds);
      return $tasks;
    }
    
    public function tasksLate($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $tasksLate = $this->DashboardFactory->tasksLate($usersIds);
      return $tasksLate;
    }
    
    public function lastTasksPerformed($parametro) {
      $usersIds = implode(',',$parametro['usersIds']); // Transforma o array em uma string com os ids

      $lastTask = $this->DashboardFactory->lastTasksPerformed($usersIds);
      return $lastTask;
    }
    
    public function dataBaseChartPie($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $dbcp = $this->DashboardFactory->dataBaseChartPie($usersIds);
      // debugApi([$dbcp]);
      return $dbcp;
    }
    
    public function dataBaseChartBar($parametro) {
      $usersIds = implode(',',$parametro['usersIds']);

      $dbcb = $this->DashboardFactory->dataBaseChartBar($usersIds);
      return $dbcb;
    }
}